@@ -24,7 +24,7 @@ use POE::Component::IRC::Plugin::NickServID;
 use Socket qw(inet_ntoa);
 use YAML::XS qw(LoadFile);
 
-our $VERSION    = '0.4.3';
+our $VERSION    = '0.4.4';
 our $HOMEPAGE   = 'http://search.cpan.org/perldoc?App::Bondage';
 our $CRYPT_SALT = 'erxpnUyerCerugbaNgfhW';
 
@@ -64,6 +64,7 @@ sub _start {
             Username     => $network->{username},
             Ircname      => $network->{realname},
             AwayPoll     => $network->{away_poll},
+            Flood        => $network->{flood},
             Resolver     => $self->{resolver},
             Debug        => $self->{Debug},
             plugin_debug => $self->{Debug},
@@ -464,6 +465,12 @@ Your IRC user name.
 
 Your IRC real name, or email, or whatever.
 
+=head3 C<flood>
+
+(optional, default: I<false>)
+
+Set to a true value to allow flooding (disables flood protection).
+
 =head3 C<channels>
 
 (optional, no default)
